// Provides the defaults of sizes, sounds, and images for a game.
// Also controls how keyboard input is mapped to an action in the game.
// By subclassing this class, you could create a new "skin" for the game.
//
// Do NOT modify this file.

public class Config
{
    // Translates a letter hit by the player into the action that that
    // key causes to happen in the game. Currently this is just the
    // cardinal direction that the hero is attempting to move in.
    // If the character isn't a direction, returns INVALID.
    public Action mapKeyToAction(char ch)
    {
        switch (ch)
        {
            case 'w':  return Action.NORTH;
            case 's':  return Action.SOUTH;
            case 'a':  return Action.WEST;
            case 'd':  return Action.EAST;
            default :  return Action.INVALID;                
        }
    }
    
    // Maps a specified item type to the image that is used to display it
    public String mapItemToImage(Item item)
    {
        switch (item)
        {
            case KEY: return "key.png";
            case GEM: return "gem.png";
            default:  return "";
        }
    }
    
    // Maps a specified item type to the sound file played when it is collected
    public String mapItemToCollectSound(Item item)
    {
        switch (item)
        {
            case KEY: return "key.wav";
            case GEM: return "gem.wav";
            default:  return "";
        }
    }
    
    // Maps a specified item type to the sound file played when an item is used    
    public String mapItemToUseSound(Item item)
    {
        switch (item)
        {
            case KEY: return "open.wav";
            default:  return "";
        }
    }

    // Returns the cell size in pixels
    public int cellPixels()
    {
        return 32;
    }
    
    // Returns filename of the sound played when walking
    public String walkSound()
    {
        return "walk.wav";
    }
    
    // Returns filename of the sound played when hero hits a wall
    public String hitWallSound()
    {
        return "wall.wav";
    }
        
    // Returns filename of the default image used for the hero
    public String heroImage()
    {
        return "girl.png";
    }

    // Returns filename of the wall image 
    public String wallImage()
    {
        return "wall.png";
    }
        
    // Returns filename of the passageway image 
    public String passageImage()
    {
        return "passage.png";
    }

    // Returns filename of an open door image 
    public String openDoorImage()
    {
        return "door_open.png";
    }

    // Returns filename of an open door image 
    public String closedDoorImage()
    {
        return "door_closed.png";
    }
    
}
